use fixed_queue::Spsc;
static mut SPSC: Spsc<u8, 4> = Spsc::new();

fn main() {
    let (sender, recver) = unsafe { SPSC.channel() };
    //panic: unsafe { SPSC.channel() };

    assert_eq!(unsafe { SPSC.capacity() }, 4);
    assert!(sender.send(1).is_ok());
    assert!(sender.send(2).is_ok());
    assert!(sender.send(3).is_ok());
    assert!(sender.send(4).is_ok());
    assert!(sender.send(5).is_err());
    println!("{:?}", recver.try_recv());
    println!("{:?}", recver.try_recv());
    println!("{:?}", recver.try_recv());
    println!("{:?}", recver.try_recv());
    println!("{:?}", recver.try_recv());
    println!("{:?}", recver.try_recv());
}
